@@ -103,8 +103,8 @@ def generateFont(options, font):
     year = datetime.now().year
     with open(options.license) as fp:
         info.copyright = fp.readline().strip()
-    info.openTypeNameLicense = "This Font Software is licensed under the SIL Open Font License, Version 1.1. This license is available with a FAQ at: https://scripts.sil.org/OFL"
-    info.openTypeNameLicenseURL = "https://scripts.sil.org/OFL"
+    info.openTypeNameLicense = "This Font Software is licensed under the SIL Open Font License, Version 1.1. This license is available with a FAQ at: https://openfontlicense.org"
+    info.openTypeNameLicenseURL = "https://openfontlicense.org"
 
     markWriter = MarkFeatureWriter()
 
@@ -585,7 +585,7 @@ def _build_production_name(glyph, font):
     return glyph.name
 
 def openFont(path):
-    font = Font.open(path)
+    font = Font.open(path, validate=False)
 
     if REMOVE_GLYPHS in font.lib:
         import re
